@@ -1,6 +1,6 @@
 package Map::Tube::Delhi::Line::Yellow;
 $Map::Tube::Delhi::Line::Yellow::AUTHORITY = 'cpan:MANWAR';
-$Map::Tube::Delhi::Line::Yellow::VERSION = '0.97';
+$Map::Tube::Delhi::Line::Yellow::VERSION = '0.98';
 use 5.006;
 use strict; use warnings;
 
@@ -10,7 +10,7 @@ Map::Tube::Delhi::Line::Yellow - Delhi Metro Map: Yellow Line.
 
 =head1 VERSION
 
-version 0.97
+version 0.98
 
 =head1 DESCRIPTION
 
@@ -91,50 +91,49 @@ map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =head1 AUTHOR
 
-Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
+Mohammad Sajid Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 REPOSITORY
 
 L<https://github.com/manwar/Map-Tube-Delhi>
 
+=head1 SEE ALSO
+
+L<Map::Tube::CLI>
+
 =head1 BUGS
 
-Please  report any bugs/feature requests to C<bug-map-tube-delhi at rt.cpan.org>,
-or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Map-Tube-Delhi>.
-I will be notified, and then you'll automatically be notified of progress on your
+Please report any bugs or feature requests through the web interface at L<https://github.com/manwar/Map-Tube-Delhi/issues>.
+I will  be notified and then you'll automatically be notified of progress on your
 bug as I make changes.
 
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc Map::Tube::Delhi::Line::Yellow
+    perldoc Map::Tube::Delhi
 
 You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker (report bugs here)
+=item * BUG Report
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Map-Tube-Delhi>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Map-Tube-Delhi>
+L<https://github.com/manwar/Map-Tube-Delhi/issues>
 
 =item * CPAN Ratings
 
 L<http://cpanratings.perl.org/d/Map-Tube-Delhi>
 
-=item * Search CPAN
+=item * Search MetaCPAN
 
-L<http://search.cpan.org/dist/Map-Tube-Delhi/>
+L<https://metacpan.org/dist/Map-Tube-Delhi/>
 
 =back
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2014 - 2019 Mohammad S Anwar.
+Copyright (C) 2014 - 2025 Mohammad Sajid Anwar.
 
 This program  is  free software; you can redistribute it and / or modify it under
 the  terms  of the the Artistic License  (2.0). You may obtain a copy of the full
